@@ -1,4 +1,4 @@
-{-# LANGUAGE ForeignFunctionInterface, CPP, MultiParamTypeClasses #-}
+{-# LANGUAGE ForeignFunctionInterface #-}
 
 -- |
 -- Module      : Crypto.Hash.SHA384
@@ -11,7 +11,6 @@
 --
 module Crypto.Hash.SHA384
     ( Ctx(..)
-    , SHA384
 
     -- * Incremental hashing Functions
     , init     -- :: Ctx
@@ -37,32 +36,7 @@ import Data.ByteString.Internal (create, toForeignPtr)
 import Data.Word
 import Crypto.Hash.Internal (unsafeDoIO)
 
-#ifdef HAVE_CRYPTOAPI
-
-import Control.Monad (liftM)
-import Data.Serialize (Serialize(..))
-import Data.Serialize.Get (getByteString)
-import Data.Serialize.Put (putByteString)
-import Data.Tagged (Tagged(..))
-import qualified Crypto.Classes as C (Hash(..))
-
-instance C.Hash Ctx SHA384 where
-    outputLength    = Tagged (48 * 8)
-    blockLength     = Tagged (128 * 8)
-    initialCtx      = init
-    updateCtx       = update
-    finalize ctx bs = Digest . finalize $ update ctx bs
-
-instance Serialize SHA384 where
-    get            = liftM Digest (getByteString digestSize)
-    put (Digest d) = putByteString d
-
-#endif
-
 newtype Ctx = Ctx ByteString
-data SHA384 = Digest !ByteString
-    deriving (Eq,Ord,Show)
-
 
 {-# INLINE digestSize #-}
 digestSize :: Int
