@@ -1,4 +1,4 @@
-{-# LANGUAGE ForeignFunctionInterface, CPP, MultiParamTypeClasses #-}
+{-# LANGUAGE ForeignFunctionInterface #-}
 
 -- |
 -- Module      : Crypto.Hash.Skein256
@@ -11,7 +11,6 @@
 --
 module Crypto.Hash.Skein256
     ( Ctx(..)
-    , Skein256
 
     -- * Incremental hashing Functions
     , init     -- :: Int -> Ctx
@@ -36,32 +35,7 @@ import Data.ByteString.Internal (create, toForeignPtr)
 import Data.Word
 import Crypto.Hash.Internal (unsafeDoIO)
 
-#ifdef HAVE_CRYPTOAPI
-
-import Control.Monad (liftM)
-import Data.Serialize (Serialize(..))
-import Data.Serialize.Get (getByteString)
-import Data.Serialize.Put (putByteString)
-import Data.Tagged (Tagged(..))
-import qualified Crypto.Classes as C (Hash(..))
-
-instance C.Hash Ctx Skein256 where
-    outputLength    = Tagged (32 * 8)
-    blockLength     = Tagged (32 * 8)
-    initialCtx      = init (32 * 8)
-    updateCtx       = update
-    finalize ctx bs = Digest . finalize $ update ctx bs
-
-instance Serialize Skein256 where
-    get            = liftM Digest (getByteString 32)
-    put (Digest d) = putByteString d
-
-#endif
-
 newtype Ctx = Ctx ByteString
-data Skein256 = Digest !ByteString
-    deriving (Eq,Ord,Show)
-
 
 {-# INLINE sizeCtx #-}
 sizeCtx :: Int
